"use client";

import { format } from "date-fns";
import { Card } from "@/components/ui/card";
import { Badge } from "@/components/ui/badge";
import { Button } from "@/components/ui/button";
import { Application, ApplicationStatus } from "@/types/application";
import { ExternalLink, Clock, Calendar } from "lucide-react";
import Image from "next/image";

const statusColors: Record<ApplicationStatus, string> = {
  submitted: "bg-green-500",
  "in-progress": "bg-yellow-500",
  pending: "bg-blue-500",
  rejected: "bg-red-500",
  accepted: "bg-purple-500",
};

interface ApplicationCardProps {
  application: Application;
}

export default function ApplicationCard({ application }: ApplicationCardProps) {
  const daysUntilDeadline = Math.ceil(
    (new Date(application.deadline).getTime() - new Date().getTime()) / (1000 * 60 * 60 * 24)
  );

  return (
    <Card className="p-6 hover:shadow-lg transition-shadow duration-300">
      <div className="flex items-start gap-6">
        <div className="relative h-16 w-16 flex-shrink-0">
          <Image
            src={application.schoolLogo}
            alt={application.schoolName}
            fill
            className="object-contain"
          />
        </div>

        <div className="flex-1 min-w-0">
          <div className="flex items-start justify-between gap-4">
            <div>
              <h3 className="text-lg font-semibold truncate">{application.schoolName}</h3>
              <p className="text-muted-foreground">{application.programName}</p>
            </div>
            <Badge
              variant="secondary"
              className={`${statusColors[application.status]} text-white`}
            >
              {application.status}
            </Badge>
          </div>

          <div className="mt-4 flex flex-wrap items-center gap-4 text-sm">
            <div className="flex items-center gap-1 text-muted-foreground">
              <Calendar className="h-4 w-4" />
              <span>Deadline: {format(new Date(application.deadline), "MMM d, yyyy")}</span>
            </div>
            <div className="flex items-center gap-1 text-muted-foreground">
              <Clock className="h-4 w-4" />
              <span>{daysUntilDeadline} days remaining</span>
            </div>
          </div>

          <div className="mt-4 flex flex-wrap items-center gap-4">
            <Button variant="outline" className="gap-2">
              <ExternalLink className="h-4 w-4" />
              Open Portal
            </Button>
            <Button variant="outline">View Details</Button>
          </div>
        </div>
      </div>
    </Card>
  );
}